@@ -31,6 +31,7 @@ from zibanu.django.rest_framework.viewsets import ViewSet
 from zibanu.django.utils import CodeGenerator
 from zibanu.django.utils import ErrorMessages
 
+from oasis.tasks import sync_company
 
 class OasisAuthServices(ViewSet):
     """
@@ -147,6 +148,8 @@ class OasisAuthServices(ViewSet):
                                http_status=status.HTTP_412_PRECONDITION_FAILED) from exc
         except APIException as exc:
             raise APIException(exc.detail.get("message"), exc.detail.get("detail"), exc.status_code) from exc
+        except Exception as exc:
+            raise APIException(str(exc)) from exc
         else:
             return Response(status=status_return, data=data_result)
 
@@ -186,7 +189,7 @@ class OasisAuthServices(ViewSet):
                         cache.set(cache_key, data_cache, self.__cache_timeout_seconds)
                         status_return = status.HTTP_200_OK
                     else:
-                        raise AuthenticationFailed(_("The email/password does not match."))
+                        raise AuthenticationFailed(_("The email/password is incorrect."))
                 else:
                     raise ValidationError(ErrorMessages.DATA_REQUEST_NOT_FOUND)
             else:
@@ -194,6 +197,6 @@ class OasisAuthServices(ViewSet):
         except ValidationError as exc:
             raise APIException(msg=exc.detail[0], error="login", http_status=exc.status_code) from exc
         except self.__user.DoesNotExist as exc:
-            raise APIException(msg=_("The email is not registered."), error="login") from exc
+            raise APIException(msg=_("The email/password is incorrect."), error="login") from exc
         else:
             return Response(status=status_return, data=data_return)
